@@ -4,9 +4,9 @@ module PDF
       def initialize(options)
         normalize_metadata(options)
 
-        if options[:template]
-          @store = PDF::Core::ObjectStore.new(:template => options[:template])
-          @store.info.data.merge!(options[:info]) if options[:info]
+        if options[:print_scaling]
+          @store = PDF::Core::ObjectStore.new(:info => options[:info], 
+                                              :print_scaling => options[:print_scaling])
         else
           @store = PDF::Core::ObjectStore.new(:info => options[:info])
         end
